# Management Groups
    
> see https://aka.ms/autorest

This is the AutoRest configuration file for Management Groups.



---
## Getting Started 
To build the SDK for Management Groups, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration

### Basic Information 
These are the global settings for the API.

``` yaml
openapi-type: arm
tag: package-2018-03
```
### Tag: package-2018-03
These settings apply only when `--tag=package-2018-03` is specified on the command line.

``` yaml $(tag) == 'package-2018-03'
input-file:
  - Microsoft.Management/preview/2018-03-01-preview/management.json
```

### Tag: package-2018-01
These settings apply only when `--tag=package-2018-01` is specified on the command line.

``` yaml $(tag) == 'package-2018-01'
input-file:
  - Microsoft.Management/preview/2018-01-01-preview/management.json
```

### Tag: package-2017-11
These settings apply only when `--tag=package-2017-11` is specified on the command line.

``` yaml $(tag) == 'package-2017-11'
input-file:
  - Microsoft.Management/preview/2017-11-01-preview/management.json
```

### Tag: package-2017-08
These settings apply only when `--tag=package-2017-08` is specified on the command line.

``` yaml $(tag) == 'package-2017-08'
input-file:
  - Microsoft.Management/preview/2017-08-31-preview/management.json
```

---
# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
```

## C# 

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.ManagementGroups
  output-folder: $(csharp-sdks-folder)/ManagementGroups/Management.ManagementGroups/Generated
  clear-output-folder: true
```

## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.
Use `--python-mode=update` if you already have a setup.py and just want to update the code itself.

``` yaml $(python)
python-mode: create
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 1
  namespace: azure.mgmt.managementgroups
  package-name: azure-mgmt-managementgroups
  clear-output-folder: true
```
``` yaml $(python) && $(python-mode) == 'update'
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/azure-mgmt-managementgroups/azure/mgmt/managementgroups
```
``` yaml $(python) && $(python-mode) == 'create'
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/azure-mgmt-managementgroups
```

## Go

These settings apply only when `--go` is specified on the command line.

``` yaml $(go)
go:
  license-header: MICROSOFT_APACHE_NO_VERSION
  clear-output-folder: true
  namespace: managementgroups
```

### Go multi-api

``` yaml $(go) && $(multiapi)
batch:
  - tag: package-2018-03
  - tag: package-2018-01
  - tag: package-2017-11
  - tag: package-2017-08
```

### Tag: package-2018-03 and go

These settings apply only when `--tag=package-2018-03 --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag)=='package-2018-03' && $(go)
output-folder: $(go-sdk-folder)/services/preview/resources/mgmt/2018-03-01-preview/management
```

### Tag: package-2018-01 and go

These settings apply only when `--tag=package-2018-01 --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag)=='package-2018-01' && $(go)
output-folder: $(go-sdk-folder)/services/preview/resources/mgmt/2018-01-01-preview/management
```

### Tag: package-2017-11 and go

These settings apply only when `--tag=package-2017-11 --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag)=='package-2017-11' && $(go)
output-folder: $(go-sdk-folder)/services/preview/resources/mgmt/2017-11-01-preview/management
```

### Tag: package-2017-08 and go

These settings apply only when `--tag=package-2017-08 --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag)=='package-2017-08' && $(go)
output-folder: $(go-sdk-folder)/services/preview/resources/mgmt/2017-08-31-preview/management
```

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.managementgroups
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-managementgroups
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2017-08
  - tag: package-2017-11
  - tag: package-2018-01
  - tag: package-2018-03
```

### Tag: package-2017-08 and java

These settings apply only when `--tag=package-2017-08 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2017-08' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.managementgroups.v2017_08_31_preview
  output-folder: $(azure-libraries-for-java-folder)/managementgroups/resource-manager/v2017_08_31_preview
regenerate-manager: true
generate-interface: true
```

### Tag: package-2017-11 and java

These settings apply only when `--tag=package-2017-11 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2017-11' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.managementgroups.v2017_11_01_preview
  output-folder: $(azure-libraries-for-java-folder)/managementgroups/resource-manager/v2017_11_01_preview
regenerate-manager: true
generate-interface: true
```

### Tag: package-2018-01 and java

These settings apply only when `--tag=package-2018-01 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2018-01' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.managementgroups.v2018_01_01_preview
  output-folder: $(azure-libraries-for-java-folder)/managementgroups/resource-manager/v2018_01_01_preview
regenerate-manager: true
generate-interface: true
```

### Tag: package-2018-03 and java

These settings apply only when `--tag=package-2018-03 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2018-03' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.managementgroups.v2018_03_01_preview
  output-folder: $(azure-libraries-for-java-folder)/managementgroups/resource-manager/v2018_03_01_preview
regenerate-manager: true
generate-interface: true
```


